@@ -4,7 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "knotesmigrateapplication.h"
-
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 
 KNotesMigrateApplication::KNotesMigrateApplication()
@@ -42,3 +42,4 @@ void KNotesMigrateApplication::initializeMigrator()
     migrateInfoThemePrint.setVersion(initialVersion);
     mMigrator.insertMigrateInfo(migrateInfoThemePrint);
 }
+#endif
